skhubness.neighbors.KNeighborsClassifier
========================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: KNeighborsClassifier

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KNeighborsClassifier.__init__
      ~KNeighborsClassifier.fit
      ~KNeighborsClassifier.get_params
      ~KNeighborsClassifier.kcandidates
      ~KNeighborsClassifier.kneighbors
      ~KNeighborsClassifier.kneighbors_graph
      ~KNeighborsClassifier.predict
      ~KNeighborsClassifier.predict_proba
      ~KNeighborsClassifier.score
      ~KNeighborsClassifier.set_params
   
   

   
   
   